/*
 * Created on 01.10.2004 by HS
 * 
 */
package de.laliluna.tutorial.relation.client;

import java.rmi.RemoteException;
import java.util.Properties;

import javax.ejb.CreateException;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.rmi.PortableRemoteObject;

import de.laliluna.tutorial.library.interfaces.Book;
import de.laliluna.tutorial.library.interfaces.BookHome;
import de.laliluna.tutorial.library.interfaces.Client;
import de.laliluna.tutorial.library.interfaces.ClientHome;
import de.laliluna.tutorial.library.interfaces.LibraryManager;
import de.laliluna.tutorial.library.interfaces.LibraryManagerHome;

/**
 * @author HS
 *
 * 
 */
public class TestClient {

  private Properties properties;

  public TestClient() {
    // [laliluna] the properties specifies where the JNDI lookups for the EJBs can be made
    properties = new Properties();
    properties.put("java.naming.factory.initial",
        "org.jnp.interfaces.NamingContextFactory");
    properties.put("java.naming.factory.url.pkgs",
        "org.jboss.naming:org.jnp.interfaces");
    properties.put("java.naming.provider.url", "jnp://localhost:1099");
    properties.put("jnp.disableDiscovery", "true");
  }

  public static void main(String[] args) {
    TestClient testClient = new TestClient();
    testClient.testRelation();
  }

  public void testRelation() {
    try {
      InitialContext context = new InitialContext(properties);
      Object object;
      // [laliluna] 01.10.2004 get home interfaces
      object = context.lookup(BookHome.JNDI_NAME);
      BookHome bookHome = (BookHome) PortableRemoteObject.narrow(object,
          BookHome.class);

      object = context.lookup(ClientHome.JNDI_NAME);
      ClientHome clientHome = (ClientHome) PortableRemoteObject.narrow(object,
          ClientHome.class);

      object = context.lookup(LibraryManagerHome.JNDI_NAME);
      LibraryManagerHome libraryManagerHome = (LibraryManagerHome) PortableRemoteObject
          .narrow(object, LibraryManagerHome.class);

      // [laliluna] 01.10.2004 create a dummy book and a client
      Book book1 = bookHome.create();
      book1.setTitle("Be nice");
      book1.setAvailable(true);
      String bookId1 = book1.getId();

      Book book2 = bookHome.create();
      book2.setTitle("Be very nice");
      book2.setAvailable(true);
      String bookId2 = book2.getId();

      Client client = clientHome.create();
      client.setName("Nasty boy");
      String clientId = client.getId();

      // [laliluna] 01.10.2004 know do some business logic
      LibraryManager libraryManager = libraryManagerHome.create();
      libraryManager.lendBook(clientId, bookId1);
      libraryManager.lendBook(clientId, bookId2);
      libraryManager.returnBook(clientId, bookId1);

    } catch (ClassCastException e) {
      e.printStackTrace();
    } catch (NamingException e) {
      e.printStackTrace();
    } catch (RemoteException e) {
      e.printStackTrace();
    } catch (CreateException e) {
      e.printStackTrace();
    }

  }
}